local mod = RW:Boss("Blood-Queen Lanathel", "Icecrown Citadel", "Icecrown Citadel", "The Crimson Hall")
local L

mod.BossIcon = [[Interface\Icons\achievement_boss_lanathel]]

------------------------------------
-- Variables
-- Pact of the Darkfallen
local wPact, mPact, tPactCD
-- Swarming Shadows
local tSwarmDur, tSwarmCD, mSwarm, wSwarm
-- Slash
local tSlashDur, tSlashCD, mSlash
-- Bite
local tEssenceDur
-- Frenzy
local tFrenzyDur, wFrenzy
-- vampires
local mVampCount

-----------------------------------
-- Init

function mod:OnRegister()
	L = mod:RegisterLocale(self:GetName(), "enUS", true)
	if L then
		L.name = "Blood-Queen Lanathel"
		
		L.vamp_count = "Vampire: %s x %d"
		L.vamp_count_opt = "Show vampire count message"
		
		L.frenzy = "You need to bite someone!"
		L.frenzy_opt = "Show warning when you have to bite someone"
	end
	L = mod:GetLocale()
	mod.L = L
	
	mod:SetTrigger(38004)
	mod:SetWin()
	
	tPactCD			= self:CDTimer(30, 71340)
	tSwarm			= self:DurTargetTimer(6, 71264)
	tSwarmCD		= self:CDTimer(45, 71264)
	tSlashCD		= self:CDTimer(10, 71623, nil, nil, false)
	tSlashDur		= self:DurTargetStackTimer(15, 71623, nil, nil, false)
	
	wPact			= self:RunawayWarning(71340)
	wSwarm			= self:RunawayWarning(71264)
	
	mPact			= self:TargetMessage(71340)
	mSwarm			= self:TargetMessage(71264)
	mSlash			= self:TargetStackMessage(71623, nil, nil, false)
	
	-- Bite
	tEssenceDur		= self:DurTimer(60, 70867)
	tFrenzyDur		= self:DurTimer(10, 70877)
	
	mVampCount		= self:CustomMessage(L.vamp_count, L.vamp_count_opt, 70867)
	wFrenzy			= self:CustomWarning(L.frenzy, L.frenzy_opt, 70877)
end

-----------------------------------------
-- Locals
local vampCount
local vamps = {}

-----------------------------------------
-- Start

function mod:OnEngage(trigger)
	self:Track("Pact", 71340)
	self:Track("Swarm", 71264)
	self:Track("Slash", 71623)
	self:Track("Essence", 70867)
	self:Track("Frenzy", 70877)

	vampCount = 0
	wipe(vamps)
end

function mod:Pact(event, args)
	if event == "SPELL_AURA_APPLIED" then
		if args:IsPlayer() then
			wPact:Show()
		end
		mPact:AddDelayTarget(args.dName)
		mPact:DelayedShow(0.2)
		tPactCD:Start()
	end
end

function mod:Swarm(event, args)
	if event == "SPELL_AURA_APPLIED" then
		if args:IsPlayer() then
			wSwarm:Show()
		end
		mSwarm:Show(args.dName)
		tSwarmDur:Start(args.dName)
		tSwarmCD:Start()
	end
end

function mod:Slash(event, args)
	if event == "SPELL_AURA_APPLIED" or event == "SPELL_AURA_APPLIED_DOSE" then
		mSlash:Show(args.dName, args.amount or 1)
		tSlashDur:Start(args.dName, args.amount or 1)
		tSlashCD:Start()
	
	elseif event == "SPELL_AURA_REMOVED" then
		tSlashDur:Stop(args.dName)
	end
end

--------------------
-- Bite
function mod:Essence(event, args)
	if event == "SPELL_AURA_APPLIED" or event == "SPELL_AURA_REFRESHED" then
		if not vamps[args.dName] then
			vamps[args.dName] = true
			vampCount = vampCount + 1
			mVampCount:Show(args.dName, vampCount)
		end
		if args:IsPlayer() then
			tEssenceDur:Start()
		end
	end
end

function mod:Frenzy(event, args)
	if event == "SPELL_AURA_APPLIED" then
		if args:IsPlayer() then
			wFrenzy:Show()
		end
	end
end

